@@ -27,7 +27,7 @@ class TreeAPIView(ListAPIView):
     def list(self, request, *args, **kwargs):
         queryset = self.filter_queryset(self.get_queryset())
         serializer = self.get_serializer(queryset, many=True)
-        parent = request.query_params.get('parent', None)
+        parent = request.query_params.get('parent', 0)
         data = get_tree(serializer.data, parent)
         return Response(data)
 
