@@ -11,6 +11,8 @@ from wechatpy import parse_message, create_reply, utils
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat
 from . import MiniProgram, OfficialAccount, WXBizDataCrypt, official_account_oauth
 
+from .models import WeChatUser
+
 
 class JSSdk(APIView):
     permission_classes = ()
@@ -104,12 +106,12 @@ class OAuth(APIView):
                 'language': user_info.get('language', '')
             }
 
-            wechat_queryset = UesrModel.objects.filter(
+            wechat_queryset = WeChatUser.objects.filter(
                 openid=user_info['openid']).first()
             if wechat_queryset:
                 wechat_queryset.update(**user_data)
             else:
-                wechat_queryset = UesrModel.objects.create(**user_data)
+                wechat_queryset = WeChatUser.objects.create(**user_data)
 
             token = jwt_create_token_wechat(
                 openid=wechat_queryset.openid, unionid=wechat_queryset.unionid, wechat_id=wechat_queryset.pk)
